#
# spec file for package zanshin
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           zanshin
Version:        0.5.71
Release:        lp152.1.9
Summary:        TODO Application
License:        GPL-2.0-only
Group:          Productivity/Office/Organizers
URL:            https://zanshin.kde.org
Source:         https://download.kde.org/stable/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  boost-devel
BuildRequires:  kf5-filesystem
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Akonadi)
BuildRequires:  cmake(KF5AkonadiCalendar)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KontactInterface)
BuildRequires:  cmake(KF5Runner)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
Recommends:     %{name}-lang

%description
Zanshin Todo is an application for managing your day-to-day actions.
It helps you organize and reduce the cognitive pressure of what one has to do in his
job and personal life. You will never forget anything anymore.

%lang_package

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %suse_update_desktop_file org.kde.zanshin Utility TimeUtility
%if %{with lang}
  %find_lang %{name}
%endif

%files
%license COPYING gpl-*.txt
%doc AUTHORS
%dir %{_kf5_appstreamdir}
%dir %{_kf5_iconsdir}/hicolor/256x256
%dir %{_kf5_iconsdir}/hicolor/256x256/apps
%{_kf5_applicationsdir}/org.kde.zanshin.desktop
%{_kf5_appstreamdir}/org.kde.zanshin.appdata.xml
%{_kf5_bindir}/zanshin
%{_kf5_bindir}/zanshin-migrator
%{_kf5_iconsdir}/hicolor/*/apps/zanshin.png
%{_kf5_iconsdir}/hicolor/scalable/apps/zanshin.svgz
%{_kf5_kxmlguidir}/zanshin/
%{_kf5_plugindir}/kontact_zanshinplugin.so
%{_kf5_plugindir}/krunner_zanshin.so
%{_kf5_plugindir}/zanshin_part.so
%{_kf5_servicesdir}/kontact/
%{_kf5_servicesdir}/plasma-runner-zanshin.desktop
%{_kf5_servicesdir}/zanshin_part.desktop

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING
%endif

%changelog
* Thu Feb  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.5.71. No changelog.
- Drop upstream patches:
  * 0001-Fix-compilation-with-latest-KCalCore-API-changes-Att.patch
  * 0001-Fix-build-with-Boost-1.70.0.patch
  * 0001-Look-for-AkonadiContact.patch
  * 0001-Remove-the-delegation-feature.patch
  * 0001-Fix-compilation-after-Collection-referenced-was-removed.patch
  * 0001-Fix-linking-of-the-cuke-steps.patch
  * 0001-Make-it-build-both-with-pre-and-post.patch
* Thu Oct 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the license tag. Zanshin has GPL-2.0-only and MIT files
* Fri Oct 11 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add patches to build with recent kcalendarcore versions:
  * 0001-Fix-compilation-with-latest-KCalCore-API-changes-Att.patch
  * 0001-Fix-build-with-Boost-1.70.0.patch
  * 0001-Look-for-AkonadiContact.patch
  * 0001-Remove-the-delegation-feature.patch
  * 0001-Fix-compilation-after-Collection-referenced-was-removed.patch
  * 0001-Fix-linking-of-the-cuke-steps.patch
  * 0001-Make-it-build-both-with-pre-and-post.patch
- Drop patches:
  * findKF5sooner.patch
  * useknownGCCflag.patch
  * qpointerconnect.diff
  * fix-build-with-Qt-5.6.patch
* Wed Jun 19 2019 wbauer@tmo.at
- Update findKF5sooner.patch: find AkonadiContact too to fix build
  with latest KDE Applications
* Thu Jan  4 2018 wbauer@tmo.at
- Update to 0.5.0
  * Errors coming from the system are now displayed properly in the
    main window
  * Tasks scheduled in the future can be filtered out
  * A task can be picked up as the "currently running" showing a
    nice overlay at the top of the screen, this is a reminder of
    what you're supposed to focus on
  * Projects are now displayed grouped by their containing
    collection which can help separate better visually between work
    and personal projects
  * Attachments are now supported for tasks (which nicely complete
    the "create todo" feature from KMail)
  * Tasks with recurrence are now supported (although we have a
    simple recurrence model for now)
  * And of course also a couple of minor GUI adjustments and bug
    fixes
  Under the hood, we also did some improvements:
  * Some error handling has been improved
  * Some duplicated code has been factorized
  * Some dead code has been cleaned up
  * Issues pointed out by krazy and clazy have been addressed
  * Feature level tests have been reworked and are better insulated
    from each other
  * Our code related to dates have been ported to the new KCalCore
    ABI introduced in 17.12
  * The biggest architectural change has been the introduction of a
    cache which speeds up our accesses to akonadi and allowed to
    address a few bugs (we had some views exhibiting duplicated
    items, this is now gone)
- Adjust build requirements
- Add -lang subpackage that contains translations
- Add fix-build-with-Qt-5.6.patch to make it build on Leap 42.x
- Update qpointerconnect.diff to fix another instance of the same
  "problem" and make it build with gcc 4.8 again
- Update source URL
* Fri Feb  3 2017 jengelh@inai.de
- Trim filler phrases from description.
* Mon Nov 21 2016 lbeltrame@kde.org
- Remove not needed requirement on gcc5
* Sun Nov 20 2016 mailaender@opensuse.org
- adhere to https://spdx.org/licenses/
* Tue Sep  6 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.4.1
* Tue Apr 19 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.4.0
* Sat Apr  9 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.3.91
* Sat Apr  2 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.3.81
* Tue Jan 12 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.3.1
* Fri Jan  1 2016 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.3.0
* Thu Dec 24 2015 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2.91
* Wed Dec 16 2015 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2.80
* Thu Jan  8 2015 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2.2
* Wed Aug  8 2012 cgiboudeaux@gmx.com
- Update translations
- Spec cleanup
* Mon Oct  3 2011 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2rc1
* Wed Aug 31 2011 Kevin Ottens <ervin@kde.org>
- Upgrading to 0.2beta2
* Tue Aug  2 2011 cgiboudeaux@gmx.com
- Add translations
* Wed Jul 27 2011 cgiboudeaux@gmx.com
- Spec cleanup, fixed some rpmlint warnings
* Mon Jul 18 2011 Kevin Ottens <ervin@kde.org>
- upgrading to 0.2beta1
* Tue May 10 2011 Kevin Ottens <ervin@kde.org>
- upgrading to 0.2alpha2
* Mon Feb  7 2011 Kevin Ottens <ervin@kde.org>
- Spec cleanup, fixed some rpmlint warnings
* Wed Oct 14 2009 Kevin Ottens <ervin@kde.org>
- upgrading to latest svn
* Fri Jan 30 2009 Kevin Ottens <ervin@kde.org>
- first packaging
